@@ -8,7 +8,7 @@ import cv2 as cv
 
 class Calculater():
     def __init__(self, img, edge):
-        self.img = img
+        self.img = img.astype(float)
         self.edge = edge
 
         self.find_convexhull()
@@ -24,9 +24,9 @@ class Calculater():
             new_ys = np.concatenate(
                 (ys+0.5, ys-0.5, ys+0.5, ys-0.5, ys, ys, ys, ys+0.5, ys-0.5))
             new_ys, new_xs = (new_ys*2).astype(int), (new_xs*2).astype(int)
-            self.hull = cv.convexHull(np.array([new_ys, new_xs]).T).T.reshape(2, -1)
+            self.hull = cv.convexHull(np.array([new_ys, new_xs]).T).T.reshape(2, -1).astype(float)
         else:
-            self.hull = cv.convexHull(np.transpose(np.nonzero(self.img))).T.reshape(2, -1)
+            self.hull = cv.convexHull(np.transpose(np.nonzero(self.img))).T.reshape(2, -1).astype(float)
 
 
     def calculate_minferet(self):
@@ -69,7 +69,7 @@ class Calculater():
 
         if self.edge:
             self.minf /= 2.
-            # self.minf_coords /= 2.
+            self.minf_coords /= 2.
 
 
     def calculate_maxferet(self):
@@ -94,10 +94,12 @@ class Calculater():
         t = y0 - m * x0
 
         self.maxf_angle = np.arctan(m) + np.pi/2
+        
+        # self.maxf_coords = np.array(((y0, x0), (y1, x1)) )
 
         if self.edge:
             self.maxf /= 2.
-            # self.maxf_coords /= 2.
+            self.maxf_coords /= 2
 
 
     def calculate_maxferet90(self):
